/* eslint-disable prettier/prettier */
import React, { useRef, useState } from 'react';
import { StyleSheet, View, SafeAreaView, Image, TouchableOpacity, ActivityIndicator, Text } from 'react-native';
import WebView, { WebViewMessageEvent } from 'react-native-webview';
import { buildHTML } from './iFrame';
import { Images } from './assets';
const YoutubePlayer = _ref => {
  let {
    videoId
  } = _ref;
  const webRef = useRef(null);
  const [time, setTime] = useState('00:00');
  const [loading, setLoading] = useState(true);
  const [playing, setPlaying] = useState(false);
  const [currentSecond, setCurrentSecond] = useState(0);
  const [webViewHasLoadedContent, setWebViewHasLoadedContent] = useState(false);
  const playVideo = () => {
    var _webRef$current;
    setPlaying(true);
    (_webRef$current = webRef.current) === null || _webRef$current === void 0 ? void 0 : _webRef$current.injectJavaScript('play()');
  };
  const pauseVideo = () => {
    var _webRef$current2;
    setPlaying(false);
    (_webRef$current2 = webRef.current) === null || _webRef$current2 === void 0 ? void 0 : _webRef$current2.injectJavaScript('pause()');
  };
  const seekForwardTo = () => {
    var _webRef$current3;
    let forwardSeek = currentSecond + 10;
    (_webRef$current3 = webRef.current) === null || _webRef$current3 === void 0 ? void 0 : _webRef$current3.injectJavaScript(`seekTo(${forwardSeek})`);
  };
  const seekBackTo = () => {
    var _webRef$current4;
    let backSeek = currentSecond - 10;
    (_webRef$current4 = webRef.current) === null || _webRef$current4 === void 0 ? void 0 : _webRef$current4.injectJavaScript(`seekTo(${backSeek})`);
  };
  const restartVideo = () => {
    var _webRef$current5;
    (_webRef$current5 = webRef.current) === null || _webRef$current5 === void 0 ? void 0 : _webRef$current5.injectJavaScript('seekTo(0)');
  };
  const onMessageRecieved = message => {
    const responseJSON = JSON.parse(message.nativeEvent.data);
    const minutes = Math.round(responseJSON.currentDuration / 60);
    const seconds = Math.round(responseJSON.currentDuration % 60);
    const minutesText = minutes < 10 ? `0${minutes}` : minutes;
    const secondsText = seconds < 10 ? `0${seconds}` : seconds;
    setCurrentSecond(seconds);
    setTime(`${minutesText}:${secondsText}`);
  };
  return /*#__PURE__*/React.createElement(SafeAreaView, {
    style: styles.container
  }, /*#__PURE__*/React.createElement(View, {
    style: styles.videoContainer
  }, /*#__PURE__*/React.createElement(WebView, {
    ref: webRef,
    source: {
      html: buildHTML(videoId)
    },
    allowsFullscreenVideo: false,
    allowsInlineMediaPlayback: true,
    scalesPageToFit: false,
    onMessage: onMessageRecieved,
    mediaPlaybackRequiresUserAction: false,
    startInLoadingState: true,
    onLoad: () => setLoading(false),
    renderLoading: () => /*#__PURE__*/React.createElement(ActivityIndicator, {
      size: "large",
      color: 'white',
      style: {
        position: 'absolute',
        alignSelf: 'center',
        marginTop: 95
      }
    }),
    onLoadStart: event => {
      setTimeout(() => {
        setWebViewHasLoadedContent(true);
      }, 500);
    },
    style: {
      opacity: webViewHasLoadedContent ? 1 : 0
    }
  }), loading ? null : /*#__PURE__*/React.createElement(View, {
    style: {
      height: '100%',
      width: '100%',
      position: 'absolute',
      opacity: 0.1
    }
  })), /*#__PURE__*/React.createElement(View, {
    style: styles.buttonRow
  }, /*#__PURE__*/React.createElement(TouchableOpacity, {
    style: {
      marginHorizontal: 10
    },
    activeOpacity: 1,
    onPress: seekBackTo
  }, /*#__PURE__*/React.createElement(Image, {
    source: Images.back,
    style: {
      height: 30,
      width: 30
    },
    resizeMode: "contain"
  })), !playing ? /*#__PURE__*/React.createElement(TouchableOpacity, {
    activeOpacity: 1,
    onPress: playVideo
  }, /*#__PURE__*/React.createElement(Image, {
    source: Images.play,
    style: {
      height: 50,
      width: 49
    }
  })) : /*#__PURE__*/React.createElement(TouchableOpacity, {
    activeOpacity: 1,
    onPress: pauseVideo
  }, /*#__PURE__*/React.createElement(Image, {
    source: Images.pause,
    style: {
      height: 50,
      width: 49
    },
    resizeMode: "contain"
  })), /*#__PURE__*/React.createElement(TouchableOpacity, {
    style: {
      marginHorizontal: 10
    },
    activeOpacity: 1,
    onPress: seekForwardTo
  }, /*#__PURE__*/React.createElement(Image, {
    source: Images.next,
    s: true,
    style: {
      height: 30,
      width: 30
    },
    resizeMode: "contain"
  })), /*#__PURE__*/React.createElement(View, {
    style: styles.textContainer
  }, /*#__PURE__*/React.createElement(Text, {
    style: styles.timeLabel
  }, time))));
};
const styles = StyleSheet.create({
  container: {
    ...StyleSheet.absoluteFillObject
  },
  videoContainer: {
    height: 200,
    backgroundColor: 'transparent'
  },
  buttonContainer: {
    flexDirection: 'row',
    width: '100%',
    justifyContent: 'space-around'
  },
  buttonRow: {
    height: 80,
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'center',
    borderTopLeftRadius: 20,
    borderTopRightRadius: 20,
    backgroundColor: 'white'
  },
  textContainer: {
    justifyContent: 'center',
    alignItems: 'center'
  },
  timeLabel: {
    fontWeight: 'bold',
    fontSize: 20
  }
});
export default YoutubePlayer;
//# sourceMappingURL=YoutubePlayer.js.map